@@ -9,6 +9,8 @@
 #include <inputmode/kateviinputmode.h>
 #include <katebuffer.h>
 #include <kateconfig.h>
+#include <katedocument.h>
+#include <kateview.h>
 
 using namespace KTextEditor;
 
@@ -154,6 +156,10 @@ void ModesTest::NormalMotionsTests()
     DoTest("a()", "y%x", "()");
     // Regression test for the bug I added fixing the bug above ;)
     DoTest("foo(bar)", "y%P", "foo(bar)foo(bar)");
+    // Regression test for adjacent brackets
+    DoTest("foo((bar)baz)", "y%P", "foo((bar)baz)foo((bar)baz)");
+    // Regression test for "empty" bracket ranges
+    DoTest("()123", "%%llx", "()23");
 
     // Testing percentage "<N>%"
     DoTest("10%\n20%\n30%\n40%\n50%\n60%\n70%\n80%\n90%\n100%", "20%dd", "10%\n30%\n40%\n50%\n60%\n70%\n80%\n90%\n100%");
@@ -434,6 +440,7 @@ void ModesTest::NormalMotionsTests()
     DoTest("hello. by.. another.\n", "GcisX", "hello. by.. another.\nX");
     DoTest("hello. yay\nis this a string?!?.. another.\n", "fycisX", "hello. X another.\n");
     DoTest("hello. yay\nis this a string?!?.. another.\n", "jcisX", "hello. X another.\n");
+    DoTest("This is a sentence.\nThis is another sentence.", "jdis", "This is a sentence.\n");
 
     // Around / Sentence text object ("as")
     DoTest("", "cas", "");
@@ -833,6 +840,7 @@ void ModesTest::NormalCommandsTests()
     DoTest("foo\nbar", "gqq", "foo\nbar");
     DoTest("foo\nbar", "2gqq", "foo bar");
     DoTest("foo\nbar\nbaz", "jgqj", "foo\nbar baz");
+    DoTest("foo\nbar\n\n\n", "gqap", "foo bar\n\n\n");
 
     // when setting the text to wrap at column 10, this should be re-formatted to
     // span several lines ...
@@ -1147,6 +1155,9 @@ void ModesTest::VisualMotionsTests()
     DoTest("Three. Different. Sentences.", "vapcX", "X");
     DoTest("Three. Different. Sentences.", "vipcX", "X");
     DoTest("Hello.\n", "vap\\esciX", "Hello.\nX");
+    // Make sure cursor is properly moved to the start of paragraph and sentence text objects
+    DoTest("Hello.\nWorld.", "jvapX", "");
+    DoTest("Hello.\nWorld.", "jvasX", "Hello.\n");
 
     // With count.
     DoTest("12345678", "lv3lyx", "1345678");
@@ -1334,9 +1345,9 @@ void ModesTest::VisualCommandsTests()
         BeginTest("aaaa\nbbbb\ncccc\ndddd");
         TestPressKey("lj\\ctrl-vljy");
         KateBuffer &buffer = kate_document->buffer();
-        QList<Kate::TextRange *> ranges = buffer.rangesForLine(1, kate_view, true);
+        QVector<Kate::TextRange *> ranges = buffer.rangesForLine(1, kate_view, true);
         QCOMPARE(ranges.size(), 1);
-        const KTextEditor::Range &range = ranges[0]->toRange();
+        KTextEditor::Range range = ranges[0]->toRange();
         QCOMPARE(range.start().column(), 1);
         QCOMPARE(range.end().column(), 3);
     }
