@@ -215,7 +215,7 @@ KTextEditor::Cursor KateScriptDocument::rfindInternal(int line, int column, cons
         }
 
         int foundAt;
-        while ((foundAt = textLine->string().leftRef(cursor.column()).lastIndexOf(text, -1, Qt::CaseSensitive)) >= 0) {
+        while ((foundAt = QStringView(textLine->string()).left(cursor.column()).lastIndexOf(text)) >= 0) {
             bool hasStyle = true;
             if (attribute != -1) {
                 const KTextEditor::DefaultStyle ds = m_document->highlight()->defaultStyleForAttribute(textLine->attribute(foundAt));
@@ -269,8 +269,9 @@ KTextEditor::Cursor KateScriptDocument::anchorInternal(int line, int column, QCh
 
     // cache line
     Kate::TextLine currentLine = document()->plainKateTextLine(line);
-    if (!currentLine)
+    if (!currentLine) {
         return KTextEditor::Cursor::invalid();
+    }
 
     // Move backwards char by char and find the opening character
     int count = 1;
@@ -280,8 +281,9 @@ KTextEditor::Cursor KateScriptDocument::anchorInternal(int line, int column, QCh
         if (line != cursor.line()) {
             line = cursor.line();
             currentLine = document()->plainKateTextLine(line);
-            if (!currentLine)
+            if (!currentLine) {
                 return KTextEditor::Cursor::invalid();
+            }
         }
 
         // get current char
@@ -813,8 +815,8 @@ void KateScriptDocument::setVariable(const QString &s, const QString &v)
 
 bool KateScriptDocument::_isCode(int defaultStyle)
 {
-    return (defaultStyle != KTextEditor::dsComment && defaultStyle != KTextEditor::dsAlert && defaultStyle != KTextEditor::dsString && defaultStyle != KTextEditor::dsRegionMarker && defaultStyle != KTextEditor::dsChar &&
-            defaultStyle != KTextEditor::dsOthers);
+    return (defaultStyle != KTextEditor::dsComment && defaultStyle != KTextEditor::dsAlert && defaultStyle != KTextEditor::dsString
+            && defaultStyle != KTextEditor::dsRegionMarker && defaultStyle != KTextEditor::dsChar && defaultStyle != KTextEditor::dsOthers);
 }
 
 void KateScriptDocument::indent(const QJSValue &jsrange, int change)
