@@ -3,7 +3,6 @@
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
-
 #include "kateswapdiffcreator.h"
 #include "katedocument.h"
 #include "katepartdebug.h"
@@ -15,6 +14,7 @@
 #include <KMessageBox>
 
 #include <QDir>
+#include <QTextCodec>
 
 // BEGIN SwapDiffCreator
 SwapDiffCreator::SwapDiffCreator(Kate::SwapFile *swapFile)
@@ -23,10 +23,6 @@ SwapDiffCreator::SwapDiffCreator(Kate::SwapFile *swapFile)
 {
 }
 
-SwapDiffCreator::~SwapDiffCreator()
-{
-}
-
 void SwapDiffCreator::viewDiff()
 {
     QString path = m_swapFile->fileName();
@@ -82,8 +78,8 @@ void SwapDiffCreator::viewDiff()
     // create a process for diff
     m_proc.setProcessChannelMode(QProcess::MergedChannels);
 
-    connect(&m_proc, SIGNAL(readyRead()), this, SLOT(slotDataAvailable()), Qt::UniqueConnection);
-    connect(&m_proc, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(slotDiffFinished()), Qt::UniqueConnection);
+    connect(&m_proc, &QProcess::readyRead, this, &SwapDiffCreator::slotDataAvailable, Qt::UniqueConnection);
+    connect(&m_proc, &QProcess::finished, this, &SwapDiffCreator::slotDiffFinished, Qt::UniqueConnection);
 
     // try to start diff process, if we can't be started be done with error
     m_proc.start(QStringLiteral("diff"), QStringList() << QStringLiteral("-u") << m_originalFile.fileName() << m_recoveredFile.fileName());
