@@ -23,10 +23,13 @@ using namespace KateVi;
 AppCommands *AppCommands::m_instance = nullptr;
 
 AppCommands::AppCommands()
-    : KTextEditor::Command({QStringLiteral("q"),      QStringLiteral("qa"),  QStringLiteral("qall"),    QStringLiteral("q!"),   QStringLiteral("qa!"),      QStringLiteral("qall!"), QStringLiteral("w"),    QStringLiteral("wq"),
-                            QStringLiteral("wa"),     QStringLiteral("wqa"), QStringLiteral("x"),       QStringLiteral("xa"),   QStringLiteral("new"),      QStringLiteral("vnew"),  QStringLiteral("e"),    QStringLiteral("edit"),
-                            QStringLiteral("enew"),   QStringLiteral("sp"),  QStringLiteral("split"),   QStringLiteral("vs"),   QStringLiteral("vsplit"),   QStringLiteral("only"),  QStringLiteral("tabe"), QStringLiteral("tabedit"),
-                            QStringLiteral("tabnew"), QStringLiteral("bd"),  QStringLiteral("bdelete"), QStringLiteral("tabc"), QStringLiteral("tabclose"), QStringLiteral("clo"),   QStringLiteral("close")})
+    : KTextEditor::Command({QStringLiteral("q"),      QStringLiteral("qa"),      QStringLiteral("qall"), QStringLiteral("q!"),       QStringLiteral("qa!"),
+                            QStringLiteral("qall!"),  QStringLiteral("w"),       QStringLiteral("wq"),   QStringLiteral("wa"),       QStringLiteral("wqa"),
+                            QStringLiteral("x"),      QStringLiteral("xa"),      QStringLiteral("new"),  QStringLiteral("vnew"),     QStringLiteral("e"),
+                            QStringLiteral("edit"),   QStringLiteral("enew"),    QStringLiteral("sp"),   QStringLiteral("split"),    QStringLiteral("vs"),
+                            QStringLiteral("vsplit"), QStringLiteral("only"),    QStringLiteral("tabe"), QStringLiteral("tabedit"),  QStringLiteral("tabnew"),
+                            QStringLiteral("bd"),     QStringLiteral("bdelete"), QStringLiteral("tabc"), QStringLiteral("tabclose"), QStringLiteral("clo"),
+                            QStringLiteral("close")})
     , re_write(QStringLiteral("^w(a)?$"))
     , re_close(QStringLiteral("^bd(elete)?|tabc(lose)?$"))
     , re_quit(QStringLiteral("^(w)?q(a|all)?(!)?$"))
@@ -48,11 +51,7 @@ AppCommands::~AppCommands()
 
 bool AppCommands::exec(KTextEditor::View *view, const QString &cmd, QString &msg, const KTextEditor::Range &)
 {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QStringList args(cmd.split(QRegularExpression(QStringLiteral("\\s+")), QString::SkipEmptyParts));
-#else
     QStringList args(cmd.split(QRegularExpression(QStringLiteral("\\s+")), Qt::SkipEmptyParts));
-#endif
     QString command(args.takeFirst());
 
     KTextEditor::MainWindow *mainWin = view->mainWindow();
@@ -73,7 +72,7 @@ bool AppCommands::exec(KTextEditor::View *view, const QString &cmd, QString &msg
     }
     // Other buffer commands are implemented by the KateFileTree plugin
     else if ((match = re_close.match(command)).hasMatch()) {
-        QTimer::singleShot(0, [app, view]() {
+        QTimer::singleShot(0, view, [app, view]() {
             app->closeDocument(view->document());
         });
     } else if ((match = re_quit.match(command)).hasMatch()) {
@@ -153,22 +152,17 @@ bool AppCommands::exec(KTextEditor::View *view, const QString &cmd, QString &msg
             QUrl url;
             QUrl arg2path(argument);
             if (base.isValid()) { // first try to use the same path as the current open document has
-                url = QUrl(base.resolved(arg2path)); // resolved handles the case where the args is a relative path, and is the same as using QUrl(args) elsewise
+                url =
+                    QUrl(base.resolved(arg2path)); // resolved handles the case where the args is a relative path, and is the same as using QUrl(args) elsewise
             } else { // else use the cwd
-                url = QUrl(QUrl(QDir::currentPath() + QLatin1Char('/')).resolved(arg2path)); // + "/" is needed because of https://lists.qt-project.org/pipermail/qt-interest-old/2011-May/033913.html
+                url = QUrl(QUrl::fromLocalFile(QDir::currentPath() + QLatin1Char('/'))
+                               .resolved(arg2path)); // + "/" is needed because of https://lists.qt-project.org/pipermail/qt-interest-old/2011-May/033913.html
             }
-            QFileInfo file(url.toLocalFile());
 
+            // either find existing document or just open it, openUrl will take care of non-existing files, too
             KTextEditor::Document *doc = app->findUrl(url);
-
             if (!doc) {
-                if (file.exists()) {
-                    doc = app->openUrl(url);
-                } else {
-                    if ((doc = app->openUrl(QUrl()))) {
-                        doc->saveAs(url);
-                    }
-                }
+                doc = app->openUrl(url);
             }
             if (doc) {
                 QTimer::singleShot(0, [mainWin, doc]() {
@@ -299,7 +293,7 @@ void AppCommands::closeCurrentDocument()
 {
     KTextEditor::Application *app = KTextEditor::Editor::instance()->application();
     KTextEditor::Document *doc = app->activeMainWindow()->activeView()->document();
-    QTimer::singleShot(0, [app, doc]() {
+    QTimer::singleShot(0, doc, [app, doc]() {
         app->closeDocument(doc);
     });
 }
@@ -371,11 +365,7 @@ BufferCommands::~BufferCommands()
 bool BufferCommands::exec(KTextEditor::View *view, const QString &cmd, QString &, const KTextEditor::Range &)
 {
     // create list of args
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QStringList args(cmd.split(QLatin1Char(' '), QString::KeepEmptyParts));
-#else
     QStringList args(cmd.split(QLatin1Char(' '), Qt::KeepEmptyParts));
-#endif
     QString command = args.takeFirst(); // same as cmd if split failed
     QString argument = args.join(QLatin1Char(' '));
 
