@@ -1,20 +1,8 @@
-/*  This file is part of the KDE libraries
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: KDE Developers
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "macros.h"
 #include <vimode/keyparser.h>
@@ -23,13 +11,9 @@
 
 using namespace KateVi;
 
-Macros::Macros()
-{
-}
+Macros::Macros() = default;
 
-Macros::~Macros()
-{
-}
+Macros::~Macros() = default;
 
 void Macros::writeConfig(KConfigGroup &config) const
 {
@@ -85,7 +69,7 @@ void Macros::store(const QChar &reg, const QList<QKeyEvent> &macroKeyEventLog, c
     QList<QKeyEvent> withoutClosingQ = macroKeyEventLog;
     Q_ASSERT(!macroKeyEventLog.isEmpty() && macroKeyEventLog.last().key() == Qt::Key_Q);
     withoutClosingQ.pop_back();
-    for (const QKeyEvent &keyEvent : qAsConst(withoutClosingQ)) {
+    for (const QKeyEvent &keyEvent : std::as_const(withoutClosingQ)) {
         const QChar key = KeyParser::self()->KeyEventToQChar(keyEvent);
         m_macros[reg].append(key);
     }
